@@ -1,6 +1,6 @@
 package Algorithm::Easing::Ease;
 
-use Moose;
+use Moo;
 
 use constant EPSILON => 0.000001;
 
