@@ -1,6 +1,6 @@
 package Algorithm::Easing::Linear;
 
-use Moose;
+use Moo;
 
 use Math::Trig qw(:pi);
 
@@ -54,6 +54,8 @@ Algorithm::Easing::Linear - Calculate eased translations between two positive wh
 
 =head1 SYNOPSIS
 
+        ## with mediator
+
         use Algorithm::Easing;
         use Algorithm::Easing::Linear;
 
@@ -91,13 +93,13 @@ Algorithm::Easing::Linear - Calculate eased translations between two positive wh
 =head2 ease_none
     Usage :
     
-        Parameters : 
-            Let t be time,
-            Let b be begin,
-            Let c be change,
-            Let d be duration,
-        Results :
-            Let p be position,
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
@@ -108,13 +110,13 @@ This method is used for a linear translation between two positive real whole int
 =head2 ease_in
     Usage :
     
-        Parameters : 
-            Let t be time,
-            Let b be begin,
-            Let c be change,
-            Let d be duration,
-        Results :
-            Let p be position,
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
             
         my $p = $obj->ease_in($t,$b,$c,$d);
 
@@ -125,13 +127,13 @@ This method is used for a linear translation between two positive real whole int
 =head2 ease_out
     Usage :
     
-        Parameters : 
-            Let t be time,
-            Let b be begin,
-            Let c be change,
-            Let d be duration,
-        Results :
-            Let p be position,
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
             
         my $p = $obj->ease_out($t,$b,$c,$d);
 
@@ -142,13 +144,13 @@ This method is used for a linear translation between two positive real whole int
 =head2 ease_both
     Usage :
     
-        Parameters : 
-            Let t be time,
-            Let b be begin,
-            Let c be change,
-            Let d be duration,
-        Results :
-            Let p be position,
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
