@@ -1,6 +1,6 @@
 package Algorithm::Easing::Sinusoidal;
 
-use Moose;
+use Moo;
 
 use Math::Trig qw(:pi);
 
@@ -54,6 +54,8 @@ Algorithm::Easing::Sinusoidal - Calculate eased translations between two positiv
 
 =head1 SYNOPSIS
 
+        ## with mediator
+
         use Algorithm::Easing;
         use Algorithm::Easing::Sinusoidal;
 
@@ -89,15 +91,15 @@ Algorithm::Easing::Sinusoidal - Calculate eased translations between two positiv
 =cut
 
 =head2 ease_none
-    usage :
+    Usage :
     
-        Parameters : 
-            Let t be time,
-            Let b be begin,
-            Let c be change,
-            Let d be duration,
-        Results :
-            Let p be position,
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
@@ -106,15 +108,15 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    usage :
+    Usage :
     
-        Parameters : 
-            Let t be time,
-            Let b be begin,
-            Let c be change,
-            Let d be duration,
-        Results :
-            Let p be position,
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
             
         my $p = $obj->ease_in($t,$b,$c,$d);
 
@@ -123,15 +125,15 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_out
-    usage :
+    Usage :
     
-        Parameters : 
-            Let t be time,
-            Let b be begin,
-            Let c be change,
-            Let d be duration,
-        Results :
-            Let p be position,
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
             
         my $p = $obj->ease_out($t,$b,$c,$d);
 
@@ -140,15 +142,15 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_both
-    usage :
+    Usage :
     
-        Parameters : 
-            Let t be time,
-            Let b be begin,
-            Let c be change,
-            Let d be duration,
-        Results :
-            Let p be position,
+        Arguments : 
+            t = time,
+            b = begin,
+            c = change,
+            d = duration,
+        Return :
+            p = position,
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
